﻿--
-- Silo Truck Animations
--
-- author  Mythos
-- date  18/07/2014
-- www.ARM-Team.gr
-- Copyright (C) ARM Team, All Rights Reserved.

siloAnim = {};
--________________________________________________________________________________________________________________________________________________________
function siloAnim.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:load(xmlFile)

	-- Functions
	self.OPER= SpecializationUtil.callSpecializationsFunction("OPER");
	
	-- Animations
	self.rdAnim = getXMLString(xmlFile, "vehicle.rdAnim#animationName");
	self.ldAnim = getXMLString(xmlFile, "vehicle.ldAnim#animationName");
	self.cbAnim = getXMLString(xmlFile, "vehicle.cbAnim#animationName");
	
	-- Index
	self.spoiler = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.spoiler#index"));

	-- Booleans
	self.rd = false;
	self.ld = false;
	self.cb = false;
	self.sp = true;
	
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:delete()

end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:mouseEvent(posX, posY, isDown, isUp, button)

end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:keyEvent(unicode, sym, modifier, isDown)

end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:update(dt)

	if self:getIsActiveForInput() and self:getIsActive() then
		
		if InputBinding.hasEvent(InputBinding.siloAnim_RD) then
			self:OPER(1, not self.rd);
		end;
		
		if InputBinding.hasEvent(InputBinding.siloAnim_LD) then
			self:OPER(2, not self.ld);
		end;
		
		if InputBinding.hasEvent(InputBinding.siloAnim_CB) then
			self:OPER(3, not self.cb);
		end;
		
		if InputBinding.hasEvent(InputBinding.siloAnim_SP) then
			self:OPER(4, not self.sp);
		end;
		
	end;
	
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:updateTick(dt)
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:draw()
	g_currentMission:addExtraPrintText(g_i18n:getText("siloAnim_ANIMS"));
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:OPER(mode, state, noEventSend)
	siloAnimEvent.sendEvent(self, mode, state, noEventSend);
	
	if mode==1 then
		if state then
			self:playAnimation(self.rdAnim, 1, nil, true);
			self.rd = true;
		else
			self:playAnimation(self.rdAnim, -1, nil, true);
			self.rd = false;
		end;
	elseif mode==2 then
		if state then
			self:playAnimation(self.ldAnim, 1, nil, true);
			self.ld = true;
		else
			self:playAnimation(self.ldAnim, -1, nil, true);
			self.ld = false;
		end;
	elseif mode==3 then
		if state then
			self:playAnimation(self.cbAnim, 1, nil, true);
			self.cb = true;
		else
			self:playAnimation(self.cbAnim, -1, nil, true);
			self.cb = false;
		end;
	elseif mode==4 then
		if state then
			setVisibility(self.spoiler, true);
			self.sp = true;
		else
			setVisibility(self.spoiler, false);
			self.sp = false;
		end;
	end;

end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:readStream(streamId, connection)
	self.rd = streamReadBool(streamId);
	self.ld = streamReadBool(streamId);
	self.cb = streamReadBool(streamId);
	self.sp = streamReadBool(streamId);
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:writeStream(streamId, connection)
    streamWriteBool(streamId, self.rd);
    streamWriteBool(streamId, self.ld);
	streamWriteBool(streamId, self.cb);
	streamWriteBool(streamId, self.sp);
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		self.rd = Utils.getNoNil(getXMLBool(xmlFile, key.."#rd"),false);
		self.ld = Utils.getNoNil(getXMLBool(xmlFile, key.."#ld"),false);
		self.cb = Utils.getNoNil(getXMLBool(xmlFile, key.."#cb"),false);
		self.sp = Utils.getNoNil(getXMLBool(xmlFile, key.."#sp"),true);
		
		if self.rd then
			self:playAnimation(self.rdAnim, 100, nil, true);
		end;
		if self.ld then
			self:playAnimation(self.ldAnim, 100, nil, true);
		end;
		if self.cb then
			self:playAnimation(self.cbAnim, 100, nil, true);
		end;
		setVisibility(self.spoiler, self.sp);

	end;
	
	return BaseMission.VEHICLE_LOAD_OK;
end;

--________________________________________________________________________________________________________________________________________________________
function siloAnim:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'rd="'..tostring(self.rd)..
	'" ld="'..tostring(self.ld)..
	'" cb="'..tostring(self.cb)..
	'" sp="'..tostring(self.sp)..'"';
	local nodes = nil;
	
	return attributes,nodes;
end;

--***********************************************************************************************************************************************************************************
--***********************************************************************************************************************************************************************************
siloAnimEvent = {};
siloAnimEvent_mt = Class(siloAnimEvent, Event);

InitEventClass(siloAnimEvent, "siloAnimEvent");

function siloAnimEvent:emptyNew()
    local self = Event:new(siloAnimEvent_mt);
    self.className="siloAnimEvent";
    return self;
end;

function siloAnimEvent:new(vehicle, mode, state)
    local self = siloAnimEvent:emptyNew()
    self.vehicle = vehicle;
	self.mode = mode;
	self.state = state;
    return self;
end;

function siloAnimEvent:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
	self.mode = streamReadInt32(streamId);
	self.state = streamReadBool(streamId);
    self.vehicle = networkGetObject(id);
    self:run(connection);
end;

function siloAnimEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.vehicle));
	streamWriteInt32(streamId, self.mode);
	streamWriteBool(streamId, self.state);
end;

function siloAnimEvent:run(connection)
	self.vehicle:OPER(self.mode, self.state, true);
    if not connection:getIsServer() then
        g_server:broadcastEvent(siloAnimEvent:new(self.vehicle, self.mode, self.state), nil, connection, self.vehicle);
    end;
end;

function siloAnimEvent.sendEvent(vehicle, mode, state, noEventSend)
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then
			g_server:broadcastEvent(siloAnimEvent:new(vehicle, mode, state), nil, nil, vehicle);
		else
			g_client:getServerConnection():sendEvent(siloAnimEvent:new(vehicle, mode, state));
		end;
	end;
end;
